@@ -2,10 +2,10 @@ package Test::TCP::CheckPort;
 use strict;
 use warnings;
 use base qw/Exporter/;
-use Test::TCP ();
+use Net::EmptyPort qw();
 
 our @EXPORT = qw/ check_port /;
 
-sub check_port { print Test::TCP::_check_port( @ARGV ) }
+sub check_port { print Net::EmptyPort::check_port( @ARGV ) }
 
 1;
